@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -13,6 +13,6 @@ class Connector(GenericConnector):
         GenericConnector.__init__(self)
 
     def connect(self):
-        errMsg = "on SAP MaxDB it is not possible to establish a "
+        errMsg = "on SAP MaxDB it is not (currently) possible to establish a "
         errMsg += "direct connection"
         raise SqlmapUnsupportedFeatureException(errMsg)
