@@ -42,6 +42,9 @@ def tamper(payload, **kwargs):
     retVal = payload
 
     if payload:
+        prefix, suffix = '+' * len(re.search(r"\A(\+*)", payload).group(0)), '+' * len(re.search(r"(\+*)\Z", payload).group(0))
+        retVal = retVal.strip('+')
+
         while True:
             indexes = zeroDepthSearch(retVal, '+')
 
@@ -89,4 +92,6 @@ def tamper(payload, **kwargs):
                 else:
                     break
 
+        retVal = "%s%s%s" % (prefix, retVal, suffix)
+
     return retVal
