@@ -25,6 +25,7 @@ def tamper(payload, **kwargs):
         * MySQL 4, 5.0 and 5.5
         * Oracle 10g
         * PostgreSQL 8.3, 8.4, 9.0
+        * SQLite 3
 
     Notes:
         * Useful to bypass very weak and bespoke web application firewalls
@@ -43,7 +44,7 @@ def tamper(payload, **kwargs):
         for match in re.finditer(r"\b[A-Za-z_]+\b", retVal):
             word = match.group()
 
-            if word.upper() in kb.keywords:
+            if word.upper() in kb.keywords or ("%s(" % word) in payload:
                 while True:
                     _ = ""
 
