@@ -25,7 +25,7 @@ def tamper(payload, **kwargs):
         * http://shiflett.org/blog/2006/jan/addslashes-versus-mysql-real-escape-string
 
     >>> tamper("1' AND 1=1")
-    '1%bf%27-- '
+    '1%bf%27-- -'
     """
 
     retVal = payload
@@ -46,7 +46,7 @@ def tamper(payload, **kwargs):
             _ = re.sub(r"(?i)\s*(AND|OR)[\s(]+([^\s]+)\s*(=|LIKE)\s*\2", "", retVal)
             if _ != retVal:
                 retVal = _
-                retVal += "-- "
+                retVal += "-- -"
             elif not any(_ in retVal for _ in ('#', '--', '/*')):
-                retVal += "-- "
+                retVal += "-- -"
     return retVal
